==> myfaces-core-assembly-2.3.10-src.zip: org/apache/myfaces/view/facelets/tag/jstl/core/IteratedValueExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.tag.jstl.core;

import javax.el.ELContext;
import javax.el.PropertyNotWritableException;
import javax.el.ValueExpression;

/**
 * @version $Id$
 */
public final class IteratedValueExpression extends ValueExpression
{

    private static final long serialVersionUID = 1L;

    private ValueExpression orig;

    private Object value;

    public IteratedValueExpression(ValueExpression orig, Object value)
    {
        this.orig = orig;
        this.value = value;
    }

    @Override
    public Object getValue(ELContext context)
    {
        return value;
    }

    @Override
    public void setValue(ELContext context, Object value)
    {
        context.setPropertyResolved(false);
        throw new PropertyNotWritableException();
    }

    @Override
    public boolean isReadOnly(ELContext context)
    {
        context.setPropertyResolved(false);
        return true;
    }

    @Override
    public Class getType(ELContext context)
    {
        context.setPropertyResolved(false);
        return Object.class;
    }

    @Override
    public Class getExpectedType()
    {
        return Object.class;
    }

    @Override
    public String getExpressionString()
    {
        return this.orig.getExpressionString();
    }

    @Override
    public boolean equals(Object obj)
    {
        return this.orig.equals(obj);
    }

    @Override
    public int hashCode()
    {
        return this.orig.hashCode();
    }

    @Override
    public boolean isLiteralText()
    {
        return false;
    }

}

==> myfaces-core-assembly-3.0.1-src.zip: org/apache/myfaces/view/facelets/tag/jstl/core/IteratedValueExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.tag.jstl.core;

import jakarta.el.ELContext;
import jakarta.el.PropertyNotWritableException;
import jakarta.el.ValueExpression;

/**
 * @version $Id$
 */
public final class IteratedValueExpression extends ValueExpression
{

    private static final long serialVersionUID = 1L;

    private ValueExpression orig;

    private Object value;

    public IteratedValueExpression(ValueExpression orig, Object value)
    {
        this.orig = orig;
        this.value = value;
    }

    @Override
    public Object getValue(ELContext context)
    {
        return value;
    }

    @Override
    public void setValue(ELContext context, Object value)
    {
        context.setPropertyResolved(false);
        throw new PropertyNotWritableException();
    }

    @Override
    public boolean isReadOnly(ELContext context)
    {
        context.setPropertyResolved(false);
        return true;
    }

    @Override
    public Class getType(ELContext context)
    {
        context.setPropertyResolved(false);
        return Object.class;
    }

    @Override
    public Class getExpectedType()
    {
        return Object.class;
    }

    @Override
    public String getExpressionString()
    {
        return this.orig.getExpressionString();
    }

    @Override
    public boolean equals(Object obj)
    {
        return this.orig.equals(obj);
    }

    @Override
    public int hashCode()
    {
        return this.orig.hashCode();
    }

    @Override
    public boolean isLiteralText()
    {
        return false;
    }

}
